const Lang = imports.lang;
const Main = imports.ui.main;

let overview;

function init() {
	overview = new LightweightOverview();
}

function enable() {
	overview.enable();
}

function disable() {
	overview.disable();
}


function LightweightOverview() {
    this._init();
}

LightweightOverview.prototype = {
	_init: function() {
		//search
		this.searchTab = Main.overview._viewSelector._searchTab;
		this.oldStartSearch = this.searchTab.startSearch;

		//dash
		this.showingId = null;
		this.hidingId = null;
		// store the values we are going to override
		this.old_x = Main.overview._viewSelector.actor.x;
		this.old_width = Main.overview._viewSelector.actor.get_width();
	},
	
	enable: function() {
		this.showingId = Main.overview.connect("showing", Lang.bind(this, this.showOverview));
		this.hidingId = Main.overview.connect("hiding", Lang.bind(this, this.hideOverview));
	},
	
	disable: function() {
		Main.overview.disconnect(this.showingId);
		Main.overview.disconnect(this.hidingId);
		this.revertAllChanges();
	},

	showOverview: function() {
		//activities/applications buttons
		Main.overview._viewSelector._tabBox.hide();

		//message tray
		Main.messageTray._corner.set_reactive(false);
		Main.messageTray.actor.hide();
		
		//search
		this.searchTab.startSearch = function(event){};
		this.searchTab._entry.hide();

		//dash
		Main.overview._dash.actor.hide();
		Main.overview._viewSelector.actor.set_x(0);
		Main.overview._viewSelector.actor.set_width(Main.overview._group.get_width());
		Main.overview._viewSelector.actor.queue_redraw();
	},
	
	hideOverview: function() {
		//message tray
		Main.messageTray.actor.show();
		Main.messageTray._corner.set_reactive(true);
	},

	revertAllChanges: function() {
		//activities/applications buttons
		Main.overview._viewSelector._tabBox.show();

		//message tray
		//hideOverview does a trick

		//search
		this.searchTab.startSearch = this.oldStartSearch;
		this.searchTab._entry.show();

		//dash
		Main.overview._dash.actor.show();
		Main.overview._viewSelector.actor.set_x(this.old_x);
		Main.overview._viewSelector.actor.set_width(this.old_width);
		Main.overview._viewSelector.actor.queue_redraw();
	}
};
